#!/bin/sh
export SDL_VIDEO_X11_WMCLASS=Maelstrom
/opt/maelstrom/bin/Maelstrom
